@@ -37,15 +37,17 @@ static void show_help( const char verbose )
           "implemented as a single struct plus associated functions. Both are simpler,\n"
           "easier to use, and safer than 'getopt_long'.\n"
           "\nFor maximum stability, Arg_parser is self-contained. It extracts all the\n"
-          "information it needs from its arguments to avoid refering to them later.\n"
-          "This avoids index-out-of-bounds errors.\n"
-          "\nArg_parser does not modify its arguments, nor uses any global variables. So\n"
-          "you may create more than one parser in your program if you need or want to.\n"
+          "information it needs from its arguments to avoid referring to them later.\n"
+          "This avoids index-out-of-bounds errors and allows the parser object to be\n"
+          "passed as argument to other functions for further analysis.\n"
+          "\nArg_parser does not modify its arguments (argc, argv), nor uses any global\n"
+          "variables.\n"
           "\nThe C++ version of Arg_parser can also parse options from configuration\n"
           "files.\n"
-          "\nTo use Arg_parser in your own programs simply copy the files 'carg_parser.h'\n"
-          "and 'carg_parser.c' in your source tree. See the file 'cmain.c' for an\n"
-          "example of use.\n"
+          "\nThe C version of Arg_parser is provided in the files 'carg_parser.h' and\n"
+          "'carg_parser.c'. To learn how to use Arg_parser in your C programs, see the\n"
+          "C example in the manual and the example file 'cmain.c' in the source\n"
+          "tarball.\n"
           "\nUsage: %s [options]\n", invocation_name );
   printf( "\nOptions:\n"
           "  -h, --help                   display this help and exit\n"
@@ -55,7 +57,7 @@ static void show_help( const char verbose )
           "  -c, --casual[=<arg>]         example of option with optional argument\n"
           "  -e, --empty=<arg>            example of option with maybe empty argument\n"
           "  -o <arg>                     example of short only option\n"
-          "      --orphan                 example of long only option\n"
+          "      --long-only              example of long only option\n"
           "  -q, --quiet                  quiet operation\n"
           "  -u, --uncaught               example of intentional bug\n"
           "  -v, --verbose                verbose operation\n" );
@@ -96,30 +98,41 @@ static void internal_error( const char * const msg )
   }
 
 
+static void print_opt( const char * const arg, const char * const option_name,
+                       const int code )
+  {
+  printf( "option '%s'", option_name );
+  if( arg[0] || code == 'e' ) printf( " with argument '%s'", arg );
+  if( code == INT_MIN || code == INT_MAX ) printf( " (code 0x%X)", code );
+  fputc( '\n', stdout );
+  }
+
+
 int main( const int argc, const char * const argv[] )
   {
   char verbose = 0;
+  enum { opt_lo = 256 };
   const ap_Option options[] =
     {
     /* code, long_name, has_arg (no/yes/maybe/yme) */
-    { 'a', "append",      ap_no  },
-    { 'b', "block",       ap_yes },
-    { 'c', "casual",      ap_maybe },
-    { 'e', "empty",       ap_yme },
-    { 'h', "help",        ap_no  },
-    { 'H', "hidden",      ap_no  },
-    { 'o', 0,             ap_yes },
-    { 'q', "quiet",       ap_no  },
-    { 'u', "uncaught",    ap_no  },
-    { 'v', "verbose",     ap_no  },
-    { 'V', "version",     ap_no  },
-    { 256, "orphan",      ap_no  },
-    { INT_MIN, "int-min", ap_no  },
-    { INT_MAX, "int-max", ap_no  },
-    { 0, 0,               ap_no  } };
+    { 'a', "append",       ap_no  },
+    { 'b', "block",        ap_yes },
+    { 'c', "casual",       ap_maybe },
+    { 'e', "empty",        ap_yme },
+    { 'h', "help",         ap_no  },
+    { 'H', "hidden",       ap_no  },
+    { 'o', 0,              ap_yes },
+    { 'q', "quiet",        ap_no  },
+    { 'u', "uncaught",     ap_no  },
+    { 'v', "verbose",      ap_no  },
+    { 'V', "version",      ap_no  },
+    { opt_lo, "long-only", ap_no  },
+    { INT_MIN, "int-min",  ap_no  },
+    { INT_MAX, "int-max",  ap_no  },
+    { 0, 0,                ap_no  } };
 
   Arg_parser parser;
-  int argind;
+  int argind = 0;
   if( argc > 0 ) invocation_name = argv[0];
 
   if( !ap_init( &parser, argc, argv, options, 0 ) )
@@ -127,43 +140,36 @@ int main( const int argc, const char * const argv[] )
   if( ap_error( &parser ) )				/* bad option */
     { show_error( ap_error( &parser ), 0, 1 ); return 1; }
 
-  for( argind = 0; argind < ap_arguments( &parser ); ++argind )
+  for( ; argind < ap_arguments( &parser ); ++argind )
     {
     const int code = ap_code( &parser, argind );
+    const char * const pn = ap_parsed_name( &parser, argind );
+    const char * const arg = ap_argument( &parser, argind );
     if( !code ) break;				/* no more options */
     switch( code )
       {
-      case 'a': break;				/* example, do nothing */
-      case 'b': break;				/* example, do nothing */
-      case 'c': break;				/* example, do nothing */
-      case 'e': break;				/* example, do nothing */
+      case 'a': print_opt( arg, pn, code ); break;
+      case 'b': print_opt( arg, pn, code ); break;
+      case 'c': print_opt( arg, pn, code ); break;
+      case 'e': print_opt( arg, pn, code ); break;
       case 'h': show_help( verbose ); return 0;
-      case 'H': break;				/* example, do nothing */
-      case 'o': break;				/* example, do nothing */
-      case 'q': verbose = 0; break;
+      case 'H': print_opt( arg, pn, code ); break;
+      case 'o': print_opt( arg, pn, code ); break;
+      case 'q': print_opt( arg, pn, code ); verbose = 0; break;
       /* case 'u': break; */			/* intentionally not caught */
-      case 'v': verbose = 1; break;
+      case 'v': print_opt( arg, pn, code ); verbose = 1; break;
       case 'V': show_version(); return 0;
-      case 256: break;				/* example, do nothing */
-      case INT_MIN: break;			/* example, do nothing */
-      case INT_MAX: break;			/* example, do nothing */
+      case opt_lo: print_opt( arg, pn, code ); break;
+      case INT_MIN: print_opt( arg, pn, code ); break;
+      case INT_MAX: print_opt( arg, pn, code ); break;
       default: internal_error( "uncaught option." );
       }
     } /* end process options */
 
-  for( argind = 0; argind < ap_arguments( &parser ); ++argind )
+  for( ; argind < ap_arguments( &parser ); ++argind )
     {
-    const int code = ap_code( &parser, argind );
     const char * const arg = ap_argument( &parser, argind );
-    if( code )	/* option */
-      {
-      printf( "option '%s'", ap_parsed_name( &parser, argind ) );
-      if( arg[0] || code == 'e' ) printf( " with argument '%s'", arg );
-      if( code == INT_MIN || code == INT_MAX ) printf( " (code 0x%X)", code );
-      }
-    else	/* non-option */
-      printf( "non-option argument '%s'", arg );
-    fputc( '\n', stdout );
+    printf( "non-option argument '%s'\n", arg );
     }
 
   if( !ap_arguments( &parser ) ) fputs( "Hello, world!\n", stdout );
