@@ -41,15 +41,17 @@ void show_help( const bool verbose )
                "implemented as a single struct plus associated functions. Both are simpler,\n"
                "easier to use, and safer than 'getopt_long'.\n"
                "\nFor maximum stability, Arg_parser is self-contained. It extracts all the\n"
-               "information it needs from its arguments to avoid refering to them later.\n"
-               "This avoids index-out-of-bounds errors.\n"
-               "\nArg_parser does not modify its arguments, nor uses any global variables. So\n"
-               "you may create more than one parser in your program if you need or want to.\n"
+               "information it needs from its arguments to avoid referring to them later.\n"
+               "This avoids index-out-of-bounds errors and allows the parser object to be\n"
+               "passed as argument to other functions for further analysis.\n"
+               "\nArg_parser does not modify its arguments (argc, argv), nor uses any global\n"
+               "variables.\n"
                "\nThe C++ version of Arg_parser can also parse options from configuration\n"
                "files.\n"
-               "\nTo use Arg_parser in your own programs simply copy the files 'arg_parser.h'\n"
-               "and 'arg_parser.cc' in your source tree. See the file 'main.cc' for an\n"
-               "example of use.\n"
+               "\nThe C++ version of Arg_parser is provided in the files 'arg_parser.h' and\n"
+               "'arg_parser.cc'. To learn how to use Arg_parser in your C++ programs, see\n"
+               "the C++ example in the manual and the example file 'main.cc' in the source\n"
+               "tarball.\n"
                "\nUsage: %s [options]\n", invocation_name );
   std::printf( "\nOptions:\n"
                "  -h, --help                   display this help and exit\n"
@@ -59,7 +61,7 @@ void show_help( const bool verbose )
                "  -c, --casual[=<arg>]         example of option with optional argument\n"
                "  -e, --empty=<arg>            example of option with maybe empty argument\n"
                "  -o <arg>                     example of short only option\n"
-               "      --orphan                 example of long only option\n"
+               "      --long-only              example of long only option\n"
                "  -q, --quiet                  quiet operation\n"
                "  -u, --uncaught               example of intentional bug\n"
                "  -v, --verbose                verbose operation\n" );
@@ -99,6 +101,16 @@ void internal_error( const char * const msg )
   std::exit( 3 );
   }
 
+
+void print_opt( const char * const arg, const char * const option_name,
+                const int code )
+  {
+  std::printf( "option '%s'", option_name );
+  if( arg[0] || code == 'e' ) std::printf( " with argument '%s'", arg );
+  if( code == INT_MIN || code == INT_MAX ) std::printf( " (code 0x%X)", code );
+  std::fputc( '\n', stdout );
+  }
+
 } // end namespace
 
 
@@ -107,66 +119,61 @@ int main( const int argc, const char * const argv[] )
   bool verbose = false;
   if( argc > 0 ) invocation_name = argv[0];
 
+  enum { opt_lo = 256 };
   const Arg_parser::Option options[] =
     {
     // code, long_name, has_arg (no/yes/maybe/yme)
-    { 'a', "append",      Arg_parser::no  },
-    { 'b', "block",       Arg_parser::yes },
-    { 'c', "casual",      Arg_parser::maybe },
-    { 'e', "empty",       Arg_parser::yme },
-    { 'h', "help",        Arg_parser::no  },
-    { 'H', "hidden",      Arg_parser::no  },
-    { 'o', 0,             Arg_parser::yes },
-    { 'q', "quiet",       Arg_parser::no  },
-    { 'u', "uncaught",    Arg_parser::no  },
-    { 'v', "verbose",     Arg_parser::no  },
-    { 'V', "version",     Arg_parser::no  },
-    { 256, "orphan",      Arg_parser::no  },
-    { INT_MIN, "int-min", Arg_parser::no  },
-    { INT_MAX, "int-max", Arg_parser::no  },
-    { 0, 0,               Arg_parser::no  } };
+    { 'a', "append",       Arg_parser::no  },
+    { 'b', "block",        Arg_parser::yes },
+    { 'c', "casual",       Arg_parser::maybe },
+    { 'e', "empty",        Arg_parser::yme },
+    { 'h', "help",         Arg_parser::no  },
+    { 'H', "hidden",       Arg_parser::no  },
+    { 'o', 0,              Arg_parser::yes },
+    { 'q', "quiet",        Arg_parser::no  },
+    { 'u', "uncaught",     Arg_parser::no  },
+    { 'v', "verbose",      Arg_parser::no  },
+    { 'V', "version",      Arg_parser::no  },
+    { opt_lo, "long-only", Arg_parser::no  },
+    { INT_MIN, "int-min",  Arg_parser::no  },
+    { INT_MAX, "int-max",  Arg_parser::no  },
+    { 0, 0,                Arg_parser::no  } };
 
   const Arg_parser parser( argc, argv, options );
   if( parser.error().size() )				// bad option
     { show_error( parser.error().c_str(), 0, true ); return 1; }
 
-  for( int argind = 0; argind < parser.arguments(); ++argind )
+  int argind = 0;
+  for( ; argind < parser.arguments(); ++argind )
     {
     const int code = parser.code( argind );
     if( !code ) break;				// no more options
+    const char * const pn = parser.parsed_name( argind ).c_str();
+    const char * const arg = parser.argument( argind ).c_str();
     switch( code )
       {
-      case 'a': break;				// example, do nothing
-      case 'b': break;				// example, do nothing
-      case 'c': break;				// example, do nothing
-      case 'e': break;				// example, do nothing
+      case 'a': print_opt( arg, pn, code ); break;
+      case 'b': print_opt( arg, pn, code ); break;
+      case 'c': print_opt( arg, pn, code ); break;
+      case 'e': print_opt( arg, pn, code ); break;
       case 'h': show_help( verbose ); return 0;
-      case 'H': break;				// example, do nothing
-      case 'o': break;				// example, do nothing
-      case 'q': verbose = false; break;
+      case 'H': print_opt( arg, pn, code ); break;
+      case 'o': print_opt( arg, pn, code ); break;
+      case 'q': print_opt( arg, pn, code ); verbose = false; break;
       // case 'u': break;			// intentionally not caught
-      case 'v': verbose = true; break;
+      case 'v': print_opt( arg, pn, code ); verbose = true; break;
       case 'V': show_version(); return 0;
-      case 256: break;				// example, do nothing
-      case INT_MIN: break;			// example, do nothing
-      case INT_MAX: break;			// example, do nothing
+      case opt_lo: print_opt( arg, pn, code ); break;
+      case INT_MIN: print_opt( arg, pn, code ); break;
+      case INT_MAX: print_opt( arg, pn, code ); break;
       default: internal_error( "uncaught option." );
       }
     } // end process options
 
-  for( int argind = 0; argind < parser.arguments(); ++argind )
+  for( ; argind < parser.arguments(); ++argind )
     {
-    const int code = parser.code( argind );
     const char * const arg = parser.argument( argind ).c_str();
-    if( code )	// option
-      {
-      std::printf( "option '%s'", parser.parsed_name( argind ).c_str() );
-      if( arg[0] || code == 'e' ) std::printf( " with argument '%s'", arg );
-      if( code == INT_MIN || code == INT_MAX ) std::printf( " (code 0x%X)", code );
-      }
-    else	// non-option
-      std::printf( "non-option argument '%s'", arg );
-    std::fputc( '\n', stdout );
+    std::printf( "non-option argument '%s'\n", arg );
     }
 
   if( !parser.arguments() ) std::fputs( "Hello, world!\n", stdout );
