@@ -41,22 +41,22 @@ for i in "${PARSER}" "${CPARSER}" ; do
   "$i" -v -h > /dev/null || test_failed $LINENO "$i"
 
   "$i" --append -a -b 5 --block 10 -c -carg --casual= --casual=arg -e "" \
-       -earg --empty= --emp=arg -o file --orphan --verbose file1 file2 > out ||
+       -earg --empty= --emp=arg -H -o file --l -q --verbos file1 file2 > out ||
     test_failed $LINENO "$i"
   cmp "${in}" out || test_failed $LINENO "$i"
 
   "$i" file1 file2 --append -ab5 --block=10 -c -carg --casu --casu=arg -e "" \
-       -earg --empty="" --empty=arg -ofile --orpha --verbos > out ||
+       -earg --empty="" --empty=arg -H -ofile --long-o -q --verbose > out ||
     test_failed $LINENO "$i"
   cmp "${in}" out || test_failed $LINENO "$i"
 
   "$i" --append -a file1 -b 5 --block 10 -c -carg --casual --casua=arg -e "" \
-       -e arg --empty "" --empty arg -o file file2 --orph --verbo > out ||
+       -e arg --empty "" --empty arg -H -o file file2 --lon -q --verbo > out ||
     test_failed $LINENO "$i"
   cmp "${in}" out || test_failed $LINENO "$i"
 
   "$i" --append -a -b5 --block=10 -c -carg --cas= --cas=arg -e "" file1 \
-       -e arg --emp "" --emp arg -ofile --orp --verb file2 > out ||
+       -e arg --emp "" --emp arg -H -ofile --long-only -q --verb file2 > out ||
     test_failed $LINENO "$i"
   cmp "${in}" out || test_failed $LINENO "$i"
 done
